You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@datafusion.apache.org by "qazxcdswe123 (via GitHub)" <gi...@apache.org> on 2025/03/08 10:24:33 UTC

Re: [I] [EPIC] ClickBench Improvements (Vanity Benchmark) [datafusion]

qazxcdswe123 commented on issue #14586:
URL: https://github.com/apache/datafusion/issues/14586#issuecomment-2708191051

   > On optimizer side, I am not sure if `single_distinct_to_groupby` can really improve performance in current version (it is an old rule introduced in long long ago), maybe we can check it again?
   
   On my m1 mac 16g, removing it shows no differences (and even a little faster overall). So i think we can maybe remove it?
   
   ```
   ┏━━━━━━━━━━━━━━┳━━━━━━━━━━━┳━━━━━━━━━━━┳━━━━━━━━━━━┓
   ┃ Query        ┃   op-main ┃     op-rm ┃    Change ┃
   ┡━━━━━━━━━━━━━━╇━━━━━━━━━━━╇━━━━━━━━━━━╇━━━━━━━━━━━┩
   │ QQuery 1     │ 1507.03ms │ 1477.66ms │ no change │
   │ QQuery 2     │  245.57ms │  238.16ms │ no change │
   │ QQuery 3     │  636.13ms │  641.14ms │ no change │
   │ QQuery 4     │  611.28ms │  589.80ms │ no change │
   │ QQuery 5     │ 1048.39ms │ 1029.87ms │ no change │
   │ QQuery 6     │  224.92ms │  218.53ms │ no change │
   │ QQuery 7     │ 1591.94ms │ 1592.04ms │ no change │
   │ QQuery 8     │ 1096.93ms │ 1084.95ms │ no change │
   │ QQuery 9     │ 1863.67ms │ 1781.91ms │ no change │
   │ QQuery 10    │  972.32ms │  939.49ms │ no change │
   │ QQuery 11    │  220.96ms │  219.66ms │ no change │
   │ QQuery 12    │  521.82ms │  505.83ms │ no change │
   │ QQuery 13    │ 1024.18ms │  978.79ms │ no change │
   │ QQuery 14    │  415.18ms │  407.40ms │ no change │
   │ QQuery 15    │  682.46ms │  662.86ms │ no change │
   │ QQuery 16    │  165.75ms │  165.36ms │ no change │
   │ QQuery 17    │ 1899.49ms │ 1864.64ms │ no change │
   │ QQuery 18    │ 2996.90ms │ 2976.30ms │ no change │
   │ QQuery 19    │  712.68ms │  697.34ms │ no change │
   │ QQuery 20    │  690.14ms │  670.94ms │ no change │
   │ QQuery 21    │ 2388.29ms │ 2345.82ms │ no change │
   │ QQuery 22    │  264.88ms │  265.54ms │ no change │
   └──────────────┴───────────┴───────────┴───────────┘
   ┏━━━━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━┓
   ┃ Benchmark Summary      ┃            ┃
   ┡━━━━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━┩
   │ Total Time (op-main)   │ 21780.91ms │
   │ Total Time (op-rm)     │ 21354.03ms │
   │ Average Time (op-main) │   990.04ms │
   │ Average Time (op-rm)   │   970.64ms │
   │ Queries Faster         │          0 │
   │ Queries Slower         │          0 │
   │ Queries with No Change │         22 │
   └────────────────────────┴────────────┘
   ```


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org


---------------------------------------------------------------------
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For additional commands, e-mail: github-help@datafusion.apache.org